@@ -282,6 +282,7 @@ def upgrade(state, **kwargs):
         packages=state.installstate.packages,
         editable_packages=state.installstate.editables,
         categories=state.installstate.categories,
+        index_url=state.index,
         dev=state.installstate.dev,
         system=state.system,
         lock_only=state.installstate.lock_only,
@@ -412,7 +413,7 @@ def shell(
         venv_name = os.environ.get("VIRTUAL_ENV", "UNKNOWN_VIRTUAL_ENVIRONMENT")
         if not anyway:
             echo(
-                "{} {} {}\nNo action taken to avoid nested environments.".format(
+                "{} {} {}\nNew shell not activated to avoid nested environments.".format(
                     style("Shell for"),
                     style(venv_name, fg="green", bold=True),
                     style("already activated.", bold=True),
@@ -590,6 +591,7 @@ def update(ctx, state, bare=False, dry_run=None, outdated=False, **kwargs):
         bare=bare,
         extra_pip_args=state.installstate.extra_pip_args,
         categories=state.installstate.categories,
+        index_url=state.index,
         quiet=state.quiet,
         dry_run=dry_run,
         outdated=outdated,
@@ -666,6 +668,7 @@ def run_open(state, module, *args, **kwargs):
 @system_option
 @option("--bare", is_flag=True, default=False, help="Minimal output.")
 @sync_options
+@site_packages_option
 @pass_state
 @pass_context
 def sync(ctx, state, bare=False, user=False, unused=False, **kwargs):
@@ -685,6 +688,7 @@ def sync(ctx, state, bare=False, user=False, unused=False, **kwargs):
         system=state.system,
         extra_pip_args=state.installstate.extra_pip_args,
         categories=state.installstate.categories,
+        site_packages=state.site_packages,
     )
     if retcode:
         ctx.abort()
