@@ -83,7 +83,6 @@ class SearchScope:
         redacted_index_urls = []
         if self.index_urls and self.index_urls != [PyPI.simple_url]:
             for url in self.index_urls:
-
                 redacted_index_url = redact_auth_from_url(url)
 
                 # Parse the URL
@@ -137,4 +136,6 @@ class SearchScope:
         index_urls = self.index_urls
         if project_name in self.index_lookup:
             index_urls = [self.index_lookup[project_name]]
+        else:
+            index_urls = [self.index_urls[0]]
         return [mkurl_pypi_url(url) for url in index_urls]
