@@ -1,9 +1,11 @@
 import os
 from contextlib import contextmanager
+from tempfile import NamedTemporaryFile
 from typing import Mapping, Sequence
 
 from pipenv.patched.pip._vendor.packaging.markers import Marker
 from pipenv.patched.pip._vendor.packaging.version import parse
+from pipenv.vendor.requirementslib.fileutils import create_tracked_tempdir
 from pipenv.vendor.requirementslib.models.requirements import (
     InstallRequirement,
     Requirement,
@@ -208,17 +210,16 @@ def clean_resolved_dep(dep, is_top_level=False, pipfile_entry=None):
             lockfile[key] = dep[key]
     # In case we lock a uri or a file when the user supplied a path
     # remove the uri or file keys from the entry and keep the path
-    fs_key = next(iter(k for k in ["path", "file"] if k in dep), None)
-    pipfile_fs_key = None
-    if pipfile_entry:
-        pipfile_fs_key = next(
-            iter(k for k in ["path", "file"] if k in pipfile_entry), None
-        )
-    if fs_key and pipfile_fs_key and fs_key != pipfile_fs_key:
-        lockfile[pipfile_fs_key] = pipfile_entry[pipfile_fs_key]
-    elif fs_key is not None:
-        lockfile[fs_key] = dep[fs_key]
-
+    preferred_file_keys = ["path", "file"]
+    dependency_file_key = next(iter(k for k in preferred_file_keys if k in dep), None)
+    if dependency_file_key:
+        lockfile[dependency_file_key] = dep[dependency_file_key]
+    # Pipfile entry overrides path/file from resolver
+    if pipfile_entry and isinstance(pipfile_entry, dict):
+        for k in preferred_file_keys:
+            if k in pipfile_entry.keys():
+                lockfile[k] = pipfile_entry[k]
+                break
     # If a package is **PRESENT** in the pipfile but has no markers, make sure we
     # **NEVER** include markers in the lockfile
     if "markers" in dep and dep.get("markers", "").strip():
@@ -235,7 +236,8 @@ def clean_resolved_dep(dep, is_top_level=False, pipfile_entry=None):
         else:
             try:
                 pipfile_entry = translate_markers(pipfile_entry)
-                lockfile["markers"] = pipfile_entry.get("markers")
+                if pipfile_entry.get("markers"):
+                    lockfile["markers"] = pipfile_entry.get("markers")
             except TypeError:
                 pass
     return {name: lockfile}
@@ -314,15 +316,10 @@ def prepare_constraint_file(
     sources=None,
     pip_args=None,
 ):
-    from pipenv.vendor.vistir.path import (
-        create_tracked_tempdir,
-        create_tracked_tempfile,
-    )
-
     if not directory:
         directory = create_tracked_tempdir(suffix="-requirements", prefix="pipenv-")
 
-    constraints_file = create_tracked_tempfile(
+    constraints_file = NamedTemporaryFile(
         mode="w",
         prefix="pipenv-",
         suffix="-constraints.txt",
@@ -367,8 +364,6 @@ def is_editable(pipfile_entry):
 
 @contextmanager
 def locked_repository(requirement):
-    from pipenv.vendor.vistir.path import create_tracked_tempdir
-
     if not requirement.is_vcs:
         return
     src_dir = create_tracked_tempdir(prefix="pipenv-", suffix="-src")
