@@ -12,6 +12,7 @@ from functools import lru_cache
 from pathlib import Path
 
 from pipenv.vendor import click
+from pipenv.vendor.pythonfinder.utils import ensure_path
 from pipenv.vendor.requirementslib.fileutils import normalize_drive, normalize_path
 
 from .constants import FALSE_VALUES, SCHEME_LIST, TRUE_VALUES
@@ -190,6 +191,7 @@ def get_workon_home():
             )
     # Create directory if it does not already exist
     expanded_path = Path(os.path.expandvars(workon_home)).expanduser()
+    expanded_path = ensure_path(expanded_path)
     os.makedirs(expanded_path, exist_ok=True)
     return expanded_path
 
@@ -242,17 +244,24 @@ def find_python(finder, line=None):
 
     if line and not isinstance(line, str):
         raise TypeError(f"Invalid python search type: expected string, received {line!r}")
-    if line and os.path.isabs(line):
-        if os.name == "nt":
-            line = make_posix(line)
-        return line
+    if line:
+        modified_line = line
+        if (
+            os.name == "nt"
+            and not os.path.exists(modified_line)
+            and not modified_line.lower().endswith(".exe")
+        ):
+            modified_line += ".exe"
+        if os.path.exists(modified_line) and shutil.which(modified_line):
+            return modified_line
+
     if not finder:
         from pipenv.vendor.pythonfinder import Finder
 
         finder = Finder(global_search=True)
     if not line:
         result = next(iter(finder.find_all_python_versions()), None)
-    elif line and line[0].isdigit() or re.match(r"[\d\.]+", line):
+    elif line and line[0].isdigit() or re.match(r"^\d+(\.\d+)*$", line):
         result = finder.find_python_version(line)
     else:
         result = finder.find_python_version(name=line)
